joop.web.j_env — joop 0.0.1 documentation

# joop.web.j_env

Environment management module for joop.

Important: The main purpose of this module is to be an interface layer for the jinja environment proxy

  contained within joop for cross platform purposes (ex. run with or without flask.)

This module provides functions to set and get the global templating environment for the joop instance.

Variables:
  joop_env:

    A global variable to store the current templating environment.

Functions:
  set_joop_env(value):

    Sets the global templating environment to the provided value.

    Args:

      value: The new environment to set as the global environment.

  get_joop_env():

    Retrieves the current global templating environment.

    Returns:

      The current global templating environment.

Usage:

  - Use set_joop_env(value) to set the global environment.

  - Use get_joop_env() to retrieve the current global environment.

Functions

`get_joop_env`() |
`set_joop_env`(value) |

joop.web.j_env.get_joop_env()

joop.web.j_env.set_joop_env(value)